@@ -13,7 +13,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
-// Copyright (c) 1996-2025, Live Networks, Inc.  All rights reserved
+// Copyright (c) 1996-2026, Live Networks, Inc.  All rights reserved
 // A test program that demonstrates how to stream - via unicast RTP
 // - various kinds of file on demand, using a built-in RTSP server.
 // main program
@@ -22,6 +22,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 
 #include "BasicUsageEnvironment.hh"
 #include "announceURL.hh"
+#define SERVER_USE_TLS 1//#####@@@@@
 
 UsageEnvironment* env;
 
@@ -82,7 +83,7 @@ int main(int argc, char** argv) {
 #ifndef STREAM_USING_SRTP
 #define STREAM_USING_SRTP True
 #endif
-  rtspServer->setTLSState(PATHNAME_TO_CERTIFICATE_FILE, PATHNAME_TO_PRIVATE_KEY_FILE,
+  rtspServer->setTLSState("/home/ec2-user/ca.pem", "/home/ec2-user/cakey.pem",//#####@@@@@
 			  STREAM_USING_SRTP);
 #endif
 
@@ -424,7 +425,7 @@ int main(int argc, char** argv) {
         // (Note: If the input UDP source is unicast rather than multicast, then change this to NULL.)
     portNumBits const inputPortNum = 1234;
         // This causes the server to take its input from the stream sent by the "testMPEG2TransportStreamer" demo application.
-    Boolean const inputStreamIsRawUDP = False; 
+    Boolean const inputStreamIsRawUDP = False;
     ServerMediaSession* sms
       = ServerMediaSession::createNew(*env, streamName, streamName,
 				      descriptionString);
